@@ -408,7 +408,11 @@ dmtxDecodePopulatedArray(int sizeIdx, DmtxMessage *msg, int fix)
       return NULL;
    }
 
-   DecodeDataStream(msg, sizeIdx, NULL);
+   if(DecodeDataStream(msg, sizeIdx, NULL) == DmtxFail) {
+      dmtxMessageDestroy(&msg);
+      msg = NULL;
+      return NULL;
+   }
 
    return msg;
 }
@@ -516,7 +520,7 @@ dmtxDecodeCreateDiagnostic(DmtxDecode *dec, int *totalBytes, int *headerBytes, i
    if(pnm == NULL)
       return NULL;
 
-#ifdef _VISUALC_
+#if defined(_MSC_VER) && (_MSC_VER < 1700)
    count = sprintf_s((char *)pnm, *headerBytes + 1, "P6\n%d %d\n255\n", width, height);
 #else
    count = snprintf((char *)pnm, *headerBytes + 1, "P6\n%d %d\n255\n", width, height);
