@@ -1,38 +1,25 @@
-/*
-libdmtx - Data Matrix Encoding/Decoding Library
-
-Copyright (c) 2008 Mike Laughton
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-Contact: mike@dragonflylogic.com
-*/
-
-/* $Id: dmtxplacemod.c 514 2008-11-19 17:10:44Z mblaughton $ */
-
 /**
- * @file dmtxplacemod.c
- * @brief Data Matrix module placement
+ * libdmtx - Data Matrix Encoding/Decoding Library
+ * Copyright 2008, 2009 Mike Laughton. All rights reserved.
+ * Copyright 2012-2016 Vadim A. Misbakh-Soloviov. All rights reserved.
+ *
+ * See LICENSE file in the main project directory for full
+ * terms of use and distribution.
+ *
+ * Contact:
+ * Vadim A. Misbakh-Soloviov <dmtx@mva.name>
+ * Mike Laughton <mike@dragonflylogic.com>
+ *
+ * \file dmtxplacemod.c
+ * \brief Data Matrix module placement
  */
 
 /**
  * receives symbol row and col and returns status
- * DMTX_MODULE_ON / !DMTX_MODULE_ON (DMTX_MODULE_OFF)
- * DMTX_MODULE_ASSIGNED
- * DMTX_MODULE_VISITED
- * DMTX_MODULE_DATA / !DMTX_MODULE_DATA (DMTX_MODULE_ALIGNMENT)
+ * DmtxModuleOn / !DmtxModuleOn (DmtxModuleOff)
+ * DmtxModuleAssigned
+ * DmtxModuleVisited
+ * DmtxModuleData / !DmtxModuleData (DmtxModuleAlignment)
  * row and col are expressed in symbol coordinates, so (0,0) is the intersection of the "L"
  */
 int
@@ -55,27 +42,27 @@ dmtxSymbolModuleStatus(DmtxMessage *message, int sizeIdx, int symbolRow, int sym
    /* Solid portion of alignment patterns */
    if(symbolRow % (dataRegionRows+2) == 0 ||
          symbolCol % (dataRegionCols+2) == 0)
-      return (DMTX_MODULE_ON_RGB | (!DMTX_MODULE_DATA));
+      return (DmtxModuleOnRGB | (!DmtxModuleData));
 
    /* Horinzontal calibration bars */
    if((symbolRow+1) % (dataRegionRows+2) == 0)
-      return (((symbolCol & 0x01) ? 0 : DMTX_MODULE_ON_RGB) | (!DMTX_MODULE_DATA));
+      return (((symbolCol & 0x01) ? 0 : DmtxModuleOnRGB) | (!DmtxModuleData));
 
    /* Vertical calibration bars */
    if((symbolCol+1) % (dataRegionCols+2) == 0)
-      return (((symbolRow & 0x01) ? 0 : DMTX_MODULE_ON_RGB) | (!DMTX_MODULE_DATA));
+      return (((symbolRow & 0x01) ? 0 : DmtxModuleOnRGB) | (!DmtxModuleData));
 
    /* Data modules */
-   return (message->array[mappingRow * mappingCols + mappingCol] | DMTX_MODULE_DATA);
+   return (message->array[mappingRow * mappingCols + mappingCol] | DmtxModuleData);
 }
 
 /**
- * @brief  Logical relationship between bit and module locations
- * @param  modules
- * @param  codewords
- * @param  sizeIdx
- * @param  moduleOnColor
- * @return Number of codewords read
+ * \brief  Logical relationship between bit and module locations
+ * \param  modules
+ * \param  codewords
+ * \param  sizeIdx
+ * \param  moduleOnColor
+ * \return Number of codewords read
  */
 static int
 ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int sizeIdx, int moduleOnColor)
@@ -83,7 +70,7 @@ ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int size
    int row, col, chr;
    int mappingRows, mappingCols;
 
-   assert(moduleOnColor & (DMTX_MODULE_ON_RED | DMTX_MODULE_ON_GREEN | DMTX_MODULE_ON_BLUE));
+   assert(moduleOnColor & (DmtxModuleOnRed | DmtxModuleOnGreen | DmtxModuleOnBlue));
 
    mappingRows = dmtxGetSymbolAttribute(DmtxSymAttribMappingMatrixRows, sizeIdx);
    mappingCols = dmtxGetSymbolAttribute(DmtxSymAttribMappingMatrixCols, sizeIdx);
@@ -107,7 +94,7 @@ ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int size
       /* Sweep upward diagonally, inserting successive characters */
       do {
          if((row < mappingRows) && (col >= 0) &&
-               !(modules[row*mappingCols+col] & DMTX_MODULE_VISITED))
+               !(modules[row*mappingCols+col] & DmtxModuleVisited))
             PatternShapeStandard(modules, mappingRows, mappingCols, row, col, &(codewords[chr++]), moduleOnColor);
          row -= 2;
          col += 2;
@@ -118,7 +105,7 @@ ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int size
       /* Sweep downward diagonally, inserting successive characters */
       do {
          if((row >= 0) && (col < mappingCols) &&
-               !(modules[row*mappingCols+col] & DMTX_MODULE_VISITED))
+               !(modules[row*mappingCols+col] & DmtxModuleVisited))
             PatternShapeStandard(modules, mappingRows, mappingCols, row, col, &(codewords[chr++]), moduleOnColor);
          row += 2;
          col -= 2;
@@ -130,7 +117,7 @@ ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int size
 
    /* If lower righthand corner is untouched then fill in the fixed pattern */
    if(!(modules[mappingRows * mappingCols - 1] &
-         DMTX_MODULE_VISITED)) {
+         DmtxModuleVisited)) {
 
       modules[mappingRows * mappingCols - 1] |= moduleOnColor;
       modules[(mappingRows * mappingCols) - mappingCols - 2] |= moduleOnColor;
@@ -141,15 +128,15 @@ ModulePlacementEcc200(unsigned char *modules, unsigned char *codewords, int size
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  row
- * @param  col
- * @param  codeword
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  row
+ * \param  col
+ * \param  codeword
+ * \param  moduleOnColor
+ * \return void
  */
 static void
 PatternShapeStandard(unsigned char *modules, int mappingRows, int mappingCols, int row, int col, unsigned char *codeword, int moduleOnColor)
@@ -165,13 +152,13 @@ PatternShapeStandard(unsigned char *modules, int mappingRows, int mappingCols, i
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  codeword
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  codeword
+ * \param  moduleOnColor
+ * \return void
  */
 static void
 PatternShapeSpecial1(unsigned char *modules, int mappingRows, int mappingCols, unsigned char *codeword, int moduleOnColor)
@@ -187,13 +174,13 @@ PatternShapeSpecial1(unsigned char *modules, int mappingRows, int mappingCols, u
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  codeword
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  codeword
+ * \param  moduleOnColor
+ * \return void
  */
 static void
 PatternShapeSpecial2(unsigned char *modules, int mappingRows, int mappingCols, unsigned char *codeword, int moduleOnColor)
@@ -209,13 +196,13 @@ PatternShapeSpecial2(unsigned char *modules, int mappingRows, int mappingCols, u
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  codeword
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  codeword
+ * \param  moduleOnColor
+ * \return void
  */
 static void
 PatternShapeSpecial3(unsigned char *modules, int mappingRows, int mappingCols, unsigned char *codeword, int moduleOnColor)
@@ -231,13 +218,13 @@ PatternShapeSpecial3(unsigned char *modules, int mappingRows, int mappingCols, u
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  codeword
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  codeword
+ * \param  moduleOnColor
+ * \return void
  */
 static void
 PatternShapeSpecial4(unsigned char *modules, int mappingRows, int mappingCols, unsigned char *codeword, int moduleOnColor)
@@ -253,19 +240,19 @@ PatternShapeSpecial4(unsigned char *modules, int mappingRows, int mappingCols, u
 }
 
 /**
- * @brief  XXX
- * @param  modules
- * @param  mappingRows
- * @param  mappingCols
- * @param  row
- * @param  col
- * @param  codeword
- * @param  mask
- * @param  moduleOnColor
- * @return void
+ * \brief  XXX
+ * \param  modules
+ * \param  mappingRows
+ * \param  mappingCols
+ * \param  row
+ * \param  col
+ * \param  codeword
+ * \param  mask
+ * \param  moduleOnColor
+ * \return void
  */
 static void
-PlaceModule(unsigned char *modules, int mappingRows, int mappingCols, int row, int col, unsigned char *codeword, DmtxBitMask mask, int moduleOnColor)
+PlaceModule(unsigned char *modules, int mappingRows, int mappingCols, int row, int col, unsigned char *codeword, int mask, int moduleOnColor)
 {
    if(row < 0) {
       row += mappingRows;
@@ -277,7 +264,7 @@ PlaceModule(unsigned char *modules, int mappingRows, int mappingCols, int row, i
    }
 
    /* If module has already been assigned then we are decoding the pattern into codewords */
-   if((modules[row*mappingCols+col] & DMTX_MODULE_ASSIGNED) != 0) {
+   if((modules[row*mappingCols+col] & DmtxModuleAssigned) != 0) {
       if((modules[row*mappingCols+col] & moduleOnColor) != 0)
          *codeword |= mask;
       else
@@ -288,8 +275,8 @@ PlaceModule(unsigned char *modules, int mappingRows, int mappingCols, int row, i
       if((*codeword & mask) != 0x00)
          modules[row*mappingCols+col] |= moduleOnColor;
 
-      modules[row*mappingCols+col] |= DMTX_MODULE_ASSIGNED;
+      modules[row*mappingCols+col] |= DmtxModuleAssigned;
    }
 
-   modules[row*mappingCols+col] |= DMTX_MODULE_VISITED;
+   modules[row*mappingCols+col] |= DmtxModuleVisited;
 }
