@@ -1,37 +1,47 @@
-/*
-libdmtx - Data Matrix Encoding/Decoding Library
-
-Copyright (c) 2008 Mike Laughton
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-Contact: mike@dragonflylogic.com
-*/
-
-/* $Id: dmtxsymbol.c 514 2008-11-19 17:10:44Z mblaughton $ */
-
 /**
- * @file dmtxsymbol.c
- * @brief Data Matrix symbol attributes
+ * libdmtx - Data Matrix Encoding/Decoding Library
+ * Copyright 2008, 2009 Mike Laughton. All rights reserved.
+ * Copyright 2012-2016 Vadim A. Misbakh-Soloviov. All rights reserved.
+ * Copyright 2016 Tim Zaman. All rights reserved.
+ *
+ * See LICENSE file in the main project directory for full
+ * terms of use and distribution.
+ *
+ * Contact:
+ * Vadim A. Misbakh-Soloviov <dmtx@mva.name>
+ * Mike Laughton <mike@dragonflylogic.com>
+ *
+ * \file dmtxsymbol.c
+ * \brief Data Matrix symbol attributes
  */
 
+
 /**
- * @brief  Retrieve property based on symbol size
- * @param  attribute
- * @param  sizeIdx
- * @return Attribute value
+ * \brief  Retrieve symbol index from rows and columns
+ * \param  rows
+ * \param  cols
+ * \return sizeIdx value
+ */
+extern int 
+getSizeIdxFromSymbolDimension(int rows, int cols)
+{
+  int symbolRows, symbolCols, i;
+  for (i=0; i<30; i++){
+    symbolRows = dmtxGetSymbolAttribute(DmtxSymAttribSymbolRows, i);
+    symbolCols = dmtxGetSymbolAttribute(DmtxSymAttribSymbolCols, i);
+    if (rows==symbolRows && cols==symbolCols){
+      return i;
+    }
+  }
+  return -1;
+}
+
+
+/**
+ * \brief  Retrieve property based on symbol size
+ * \param  attribute
+ * \param  sizeIdx
+ * \return Attribute value
  */
 extern int
 dmtxGetSymbolAttribute(int attribute, int sizeIdx)
@@ -90,8 +100,8 @@ dmtxGetSymbolAttribute(int attribute, int sizeIdx)
                                                                34,  31,  31,
                                                    3,  5,  7,   9,  12,  14 };
 
-   if(sizeIdx < 0 || sizeIdx >= DMTX_SYMBOL_SQUARE_COUNT + DMTX_SYMBOL_RECT_COUNT)
-      return -1;
+   if(sizeIdx < 0 || sizeIdx >= DmtxSymbolSquareCount + DmtxSymbolRectCount)
+      return DmtxUndefined;
 
    switch(attribute) {
       case DmtxSymAttribSymbolRows:
@@ -105,9 +115,10 @@ dmtxGetSymbolAttribute(int attribute, int sizeIdx)
       case DmtxSymAttribHorizDataRegions:
          return horizDataRegions[sizeIdx];
       case DmtxSymAttribVertDataRegions:
-         return (sizeIdx < DMTX_SYMBOL_SQUARE_COUNT) ? horizDataRegions[sizeIdx] : 1;
+         return (sizeIdx < DmtxSymbolSquareCount) ? horizDataRegions[sizeIdx] : 1;
       case DmtxSymAttribMappingMatrixRows:
-         return dataRegionRows[sizeIdx] * dmtxGetSymbolAttribute(DmtxSymAttribVertDataRegions, sizeIdx);
+         return dataRegionRows[sizeIdx] *
+               dmtxGetSymbolAttribute(DmtxSymAttribVertDataRegions, sizeIdx);
       case DmtxSymAttribMappingMatrixCols:
          return dataRegionCols[sizeIdx] * horizDataRegions[sizeIdx];
       case DmtxSymAttribInterleavedBlocks:
@@ -124,14 +135,14 @@ dmtxGetSymbolAttribute(int attribute, int sizeIdx)
          return blockMaxCorrectable[sizeIdx] * interleavedBlocks[sizeIdx];
    }
 
-   return -1;
+   return DmtxUndefined;
 }
 
 /**
- * @brief  Retrieve data size for a specific symbol size and block number
- * @param  sizeIdx
- * @param  blockIdx
- * @return Attribute value
+ * \brief  Retrieve data size for a specific symbol size and block number
+ * \param  sizeIdx
+ * \param  blockIdx
+ * \return Attribute value
  */
 extern int
 dmtxGetBlockDataSize(int sizeIdx, int blockIdx)
@@ -142,38 +153,39 @@ dmtxGetBlockDataSize(int sizeIdx, int blockIdx)
 
    symbolDataWords = dmtxGetSymbolAttribute(DmtxSymAttribSymbolDataWords, sizeIdx);
    interleavedBlocks = dmtxGetSymbolAttribute(DmtxSymAttribInterleavedBlocks, sizeIdx);
-   count = (int)(symbolDataWords/interleavedBlocks);
 
    if(symbolDataWords < 1 || interleavedBlocks < 1)
-      return -1;
+      return DmtxUndefined;
+
+   count = (int)(symbolDataWords/interleavedBlocks);
 
    return (sizeIdx == DmtxSymbol144x144 && blockIdx < 8) ? count + 1 : count;
 }
 
 /**
- * @brief  Determine symbol size based on data size and requested properties
- * @param  dataWords
- * @param  sizeIdxRequest
- * @return Symbol size index (or -1 if none)
+ * \brief  Determine symbol size based on data size and requested properties
+ * \param  dataWords
+ * \param  sizeIdxRequest
+ * \return Symbol size index (or DmtxUndefined if none)
  */
 static int
-FindCorrectSymbolSize(int dataWords, int sizeIdxRequest)
+FindSymbolSize(int dataWords, int sizeIdxRequest)
 {
    int sizeIdx;
    int idxBeg, idxEnd;
 
    if(dataWords <= 0)
-      return -1;
+      return DmtxUndefined;
 
    if(sizeIdxRequest == DmtxSymbolSquareAuto || sizeIdxRequest == DmtxSymbolRectAuto) {
 
       if(sizeIdxRequest == DmtxSymbolSquareAuto) {
          idxBeg = 0;
-         idxEnd = DMTX_SYMBOL_SQUARE_COUNT;
+         idxEnd = DmtxSymbolSquareCount;
       }
       else {
-         idxBeg = DMTX_SYMBOL_SQUARE_COUNT;
-         idxEnd = DMTX_SYMBOL_SQUARE_COUNT + DMTX_SYMBOL_RECT_COUNT;
+         idxBeg = DmtxSymbolSquareCount;
+         idxEnd = DmtxSymbolSquareCount + DmtxSymbolRectCount;
       }
 
       for(sizeIdx = idxBeg; sizeIdx < idxEnd; sizeIdx++) {
@@ -182,14 +194,14 @@ FindCorrectSymbolSize(int dataWords, int sizeIdxRequest)
       }
 
       if(sizeIdx == idxEnd)
-         return -1;
+         return DmtxUndefined;
    }
    else {
       sizeIdx = sizeIdxRequest;
    }
 
    if(dataWords > dmtxGetSymbolAttribute(DmtxSymAttribSymbolDataWords, sizeIdx))
-      return -1;
+      return DmtxUndefined;
 
    return sizeIdx;
 }
