@@ -1,30 +1,17 @@
-/*
-libdmtx - Data Matrix Encoding/Decoding Library
-
-Copyright (c) 2008 Mike Laughton
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-Contact: mike@dragonflylogic.com
-*/
-
-/* $Id: dmtxvector2.c 498 2008-11-06 23:43:56Z mblaughton $ */
-
 /**
- * @file dmtxvector2.c
- * @brief 2D Vector math
+ * libdmtx - Data Matrix Encoding/Decoding Library
+ * Copyright 2008, 2009 Mike Laughton. All rights reserved.
+ * Copyright 2012-2016 Vadim A. Misbakh-Soloviov. All rights reserved.
+ *
+ * See LICENSE file in the main project directory for full
+ * terms of use and distribution.
+ *
+ * Contact:
+ * Vadim A. Misbakh-Soloviov <dmtx@mva.name>
+ * Mike Laughton <mike@dragonflylogic.com>
+ *
+ * \file dmtxvector2.c
+ * \brief 2D Vector math
  */
 
 /**
@@ -123,8 +110,8 @@ dmtxVector2Norm(DmtxVector2 *v)
 
    mag = dmtxVector2Mag(v);
 
-   if(mag <= DMTX_ALMOST_ZERO)
-      return -1.0;
+   if(mag <= DmtxAlmostZero)
+      return -1.0; /* XXX this doesn't look clean */
 
    dmtxVector2ScaleBy(v, 1/mag);
 
@@ -161,7 +148,7 @@ dmtxDistanceFromRay2(const DmtxRay2 *r, const DmtxVector2 *q)
    DmtxVector2 vSubTmp;
 
    /* Assumes that v is a unit vector */
-   assert(fabs(1.0 - dmtxVector2Mag(&(r->v))) <= DMTX_ALMOST_ZERO);
+   assert(fabs(1.0 - dmtxVector2Mag(&(r->v))) <= DmtxAlmostZero);
 
    return dmtxVector2Cross(&(r->v), dmtxVector2Sub(&vSubTmp, q, &(r->p)));
 }
@@ -175,9 +162,9 @@ dmtxDistanceAlongRay2(const DmtxRay2 *r, const DmtxVector2 *q)
 {
    DmtxVector2 vSubTmp;
 
-/* Assumes that v is a unit vector */
 #ifdef DEBUG
-   if(fabs(1.0 - dmtxVector2Mag(v)) > DMTX_ALMOST_ZERO) {
+   /* Assumes that v is a unit vector */
+   if(fabs(1.0 - dmtxVector2Mag(&(r->v))) > DmtxAlmostZero) {
       ; /* XXX big error goes here */
    }
 #endif
@@ -189,15 +176,15 @@ dmtxDistanceAlongRay2(const DmtxRay2 *r, const DmtxVector2 *q)
  *
  *
  */
-extern int
+extern DmtxPassFail
 dmtxRay2Intersect(DmtxVector2 *point, const DmtxRay2 *p0, const DmtxRay2 *p1)
 {
    double numer, denom;
    DmtxVector2 w;
 
    denom = dmtxVector2Cross(&(p1->v), &(p0->v));
-   if(fabs(denom) <= DMTX_ALMOST_ZERO)
-      return DMTX_FAILURE;
+   if(fabs(denom) <= DmtxAlmostZero)
+      return DmtxFail;
 
    dmtxVector2Sub(&w, &(p1->p), &(p0->p));
    numer = dmtxVector2Cross(&(p1->v), &w);
@@ -209,47 +196,16 @@ dmtxRay2Intersect(DmtxVector2 *point, const DmtxRay2 *p0, const DmtxRay2 *p1)
  *
  *
  */
-extern int
+extern DmtxPassFail
 dmtxPointAlongRay2(DmtxVector2 *point, const DmtxRay2 *r, double t)
 {
    DmtxVector2 vTmp;
 
    /* Ray should always have unit length of 1 */
-   assert(fabs(1.0 - dmtxVector2Mag(&(r->v))) <= DMTX_ALMOST_ZERO);
+   assert(fabs(1.0 - dmtxVector2Mag(&(r->v))) <= DmtxAlmostZero);
 
    dmtxVector2Scale(&vTmp, &(r->v), t);
    dmtxVector2Add(point, &(r->p), &vTmp);
 
-   return DMTX_SUCCESS;
-}
-
-/**
- *
- *
- */
-extern DmtxVector2
-dmtxRemoveLensDistortion(DmtxVector2 point, DmtxImage *img, double k1, double k2)
-{
-   int width, height;
-   double radiusPow2, radiusPow4;
-   double factor;
-   DmtxVector2 pointShifted;
-   DmtxVector2 correctedPoint;
-
-   /* XXX this function can be rewritten using vector math notation */
-   width = dmtxImageGetProp(img, DmtxPropScaledWidth);
-   height = dmtxImageGetProp(img, DmtxPropScaledHeight);
-
-   pointShifted.X = point.X - width/2.0;
-   pointShifted.Y = point.Y - height/2.0;
-
-   radiusPow2 = pointShifted.X * pointShifted.X + pointShifted.Y * pointShifted.Y;
-   radiusPow4 = radiusPow2 * radiusPow2;
-
-   factor = 1 + (k1 * radiusPow2) + (k2 * radiusPow4);
-
-   correctedPoint.X = pointShifted.X * factor + width/2.0;
-   correctedPoint.Y = pointShifted.Y * factor + height/2.0;
-
-   return correctedPoint;
+   return DmtxPass;
 }
